==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-mediaconvert/include/aws/mediaconvert/model/OutputChannelMapping.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/mediaconvert/MediaConvert_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace MediaConvert
{
namespace Model
{

  /**
   * OutputChannel mapping settings.<p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/mediaconvert-2017-08-29/OutputChannelMapping">AWS
   * API Reference</a></p>
   */
  class AWS_MEDIACONVERT_API OutputChannelMapping
  {
  public:
    OutputChannelMapping();
    OutputChannelMapping(Aws::Utils::Json::JsonView jsonValue);
    OutputChannelMapping& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline const Aws::Vector<int>& GetInputChannels() const{ return m_inputChannels; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline bool InputChannelsHasBeenSet() const { return m_inputChannelsHasBeenSet; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline void SetInputChannels(const Aws::Vector<int>& value) { m_inputChannelsHasBeenSet = true; m_inputChannels = value; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline void SetInputChannels(Aws::Vector<int>&& value) { m_inputChannelsHasBeenSet = true; m_inputChannels = std::move(value); }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& WithInputChannels(const Aws::Vector<int>& value) { SetInputChannels(value); return *this;}

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& WithInputChannels(Aws::Vector<int>&& value) { SetInputChannels(std::move(value)); return *this;}

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& AddInputChannels(int value) { m_inputChannelsHasBeenSet = true; m_inputChannels.push_back(value); return *this; }


    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline const Aws::Vector<double>& GetInputChannelsFineTune() const{ return m_inputChannelsFineTune; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline bool InputChannelsFineTuneHasBeenSet() const { return m_inputChannelsFineTuneHasBeenSet; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline void SetInputChannelsFineTune(const Aws::Vector<double>& value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune = value; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline void SetInputChannelsFineTune(Aws::Vector<double>&& value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune = std::move(value); }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& WithInputChannelsFineTune(const Aws::Vector<double>& value) { SetInputChannelsFineTune(value); return *this;}

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& WithInputChannelsFineTune(Aws::Vector<double>&& value) { SetInputChannelsFineTune(std::move(value)); return *this;}

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& AddInputChannelsFineTune(double value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune.push_back(value); return *this; }

  private:

    Aws::Vector<int> m_inputChannels;
    bool m_inputChannelsHasBeenSet;

    Aws::Vector<double> m_inputChannelsFineTune;
    bool m_inputChannelsFineTuneHasBeenSet;
  };

} // namespace Model
} // namespace MediaConvert
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-mediaconvert/include/aws/mediaconvert/model/OutputChannelMapping.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/mediaconvert/MediaConvert_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace MediaConvert
{
namespace Model
{

  /**
   * OutputChannel mapping settings.<p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/mediaconvert-2017-08-29/OutputChannelMapping">AWS
   * API Reference</a></p>
   */
  class AWS_MEDIACONVERT_API OutputChannelMapping
  {
  public:
    OutputChannelMapping();
    OutputChannelMapping(Aws::Utils::Json::JsonView jsonValue);
    OutputChannelMapping& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline const Aws::Vector<int>& GetInputChannels() const{ return m_inputChannels; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline bool InputChannelsHasBeenSet() const { return m_inputChannelsHasBeenSet; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline void SetInputChannels(const Aws::Vector<int>& value) { m_inputChannelsHasBeenSet = true; m_inputChannels = value; }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline void SetInputChannels(Aws::Vector<int>&& value) { m_inputChannelsHasBeenSet = true; m_inputChannels = std::move(value); }

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& WithInputChannels(const Aws::Vector<int>& value) { SetInputChannels(value); return *this;}

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& WithInputChannels(Aws::Vector<int>&& value) { SetInputChannels(std::move(value)); return *this;}

    /**
     * Use this setting to specify your remix values when they are integers, such as
     * -10, 0, or 4.
     */
    inline OutputChannelMapping& AddInputChannels(int value) { m_inputChannelsHasBeenSet = true; m_inputChannels.push_back(value); return *this; }


    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline const Aws::Vector<double>& GetInputChannelsFineTune() const{ return m_inputChannelsFineTune; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline bool InputChannelsFineTuneHasBeenSet() const { return m_inputChannelsFineTuneHasBeenSet; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline void SetInputChannelsFineTune(const Aws::Vector<double>& value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune = value; }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline void SetInputChannelsFineTune(Aws::Vector<double>&& value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune = std::move(value); }

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& WithInputChannelsFineTune(const Aws::Vector<double>& value) { SetInputChannelsFineTune(value); return *this;}

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& WithInputChannelsFineTune(Aws::Vector<double>&& value) { SetInputChannelsFineTune(std::move(value)); return *this;}

    /**
     * Use this setting to specify your remix values when they have a decimal
     * component, such as -10.312, 0.08, or 4.9. MediaConvert rounds your remixing
     * values to the nearest thousandth.
     */
    inline OutputChannelMapping& AddInputChannelsFineTune(double value) { m_inputChannelsFineTuneHasBeenSet = true; m_inputChannelsFineTune.push_back(value); return *this; }

  private:

    Aws::Vector<int> m_inputChannels;
    bool m_inputChannelsHasBeenSet = false;

    Aws::Vector<double> m_inputChannelsFineTune;
    bool m_inputChannelsFineTuneHasBeenSet = false;
  };

} // namespace Model
} // namespace MediaConvert
} // namespace Aws
